Keen | Bootstrap Select
Description: Bootstrap select examples

# Customer Relationship Management

New Order

### Bootstrap Select

Reports
The jQuery plugin that brings select elements into the 21st century with intuitive multiselection, searching, and much more.
For more info please visit the plugin's Demo Page or Github Repo.

### Bootstrap Select Examples

Minimum Setup
Options Size
Optgroups Example
Select boxes with optgroups
Multiple Select
Live Search
You can add a search input by passing `data-live-search="true"` attribute
Key Words
Add key words to options to improve their searchability using `data-tokens`
Limited Selection
Placeholder
Selected Text
Selected Text Format
Style Options
Width Options
Icons
Custom Content
Subtext
Select/deselect all options
Divider
Menu Header
Disabled
Disabled Options
Button States
Modal Demos
Launch modal examples

##### Bootstrap Touchspin Examples

Standard Input
Minimum Setup
Optgroups Example
Select boxes with optgroups
Multiple Select
Live Search
You can add a search input by passing `data-live-search="true"` attribute

### Validation State Examples

Success State
Success! You've done it.
Example help text that remains unchanged.
Warning State
Shucks, check the formatting of that and try again.
Example help text that remains unchanged.

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!